@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2013-2021 The Project Lombok Authors.
+ * Copyright (C) 2013-2025 The Project Lombok Authors.
  * 
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -65,7 +65,6 @@ import lombok.core.AST.Kind;
 import lombok.core.AnnotationValues;
 import lombok.core.HandlerPriority;
 import lombok.eclipse.EcjAugments;
-import lombok.eclipse.EclipseAST;
 import lombok.eclipse.EclipseAnnotationHandler;
 import lombok.eclipse.EclipseNode;
 import lombok.spi.Provides;
@@ -169,10 +168,15 @@ public class HandleNonNull extends EclipseAnnotationHandler<NonNull> {
 			}
 		}
 		if (posToInsert == -1) {
-			AbstractMethodDeclaration[] na = new AbstractMethodDeclaration[td.methods.length + 1];
-			posToInsert = td.methods.length;
-			System.arraycopy(td.methods, 0, na, 0, posToInsert);
-			td.methods = na;
+			if (td.methods == null) {
+				td.methods = new AbstractMethodDeclaration[1];
+				posToInsert = 0;
+			} else {
+				posToInsert = td.methods.length;
+				AbstractMethodDeclaration[] na = new AbstractMethodDeclaration[posToInsert + 1];
+				System.arraycopy(td.methods, 0, na, 0, posToInsert);
+				td.methods = na;
+			}
 		}
 		
 		ConstructorDeclaration cd = new ConstructorDeclaration(((CompilationUnitDeclaration) typeNode.top().get()).compilationResult);
@@ -187,8 +191,9 @@ public class HandleNonNull extends EclipseAnnotationHandler<NonNull> {
 		
 		for (int i = 0; i < cd.arguments.length; i++) {
 			FieldDeclaration cmp = recordComponents.get(i);
-			cd.arguments[i] = new Argument(cmp.name, cmp.sourceStart, cmp.type, 0);
+			cd.arguments[i] = new Argument(cmp.name, cmp.sourceStart, cmp.type, cmp.modifiers);
 			cd.arguments[i].bits = ASTNode.IsArgument | ASTNode.IgnoreRawTypeCheck | ASTNode.IsReachable;
+			cd.arguments[i].annotations = cmp.annotations;
 			FieldReference lhs = new FieldReference(cmp.name, 0);
 			lhs.receiver = new ThisReference(0, 0);
 			SingleNameReference rhs = new SingleNameReference(cmp.name, 0);
@@ -221,9 +226,16 @@ public class HandleNonNull extends EclipseAnnotationHandler<NonNull> {
 		// As we need both for @NonNull we reset the handled flag during diet parse.
 		
 		if (!annotationNode.isCompleteParse()) {
-			if (annotationNode.up().getKind() == Kind.FIELD) {
+			final EclipseNode node;
+			if (annotationNode.up().getKind() == Kind.TYPE_USE) {
+				node = annotationNode.directUp().directUp();
+			} else {
+				node = annotationNode.up();
+			}
+			
+			if (node.getKind() == Kind.FIELD) {
 				//Check if this is a record and we need to generate the compact form constructor.
-				EclipseNode typeNode = annotationNode.up().up();
+				EclipseNode typeNode = node.up();
 				if (typeNode.getKind() == Kind.TYPE) {
 					if (isRecord(typeNode)) {
 						addCompactConstructorIfNeeded(typeNode, annotationNode);
@@ -251,16 +263,23 @@ public class HandleNonNull extends EclipseAnnotationHandler<NonNull> {
 	private void handle0(Annotation ast, EclipseNode annotationNode, boolean force) {
 		handleFlagUsage(annotationNode, ConfigurationKeys.NON_NULL_FLAG_USAGE, "@NonNull");
 		
-		if (annotationNode.up().getKind() == Kind.FIELD) {
+		final EclipseNode node;
+		if (annotationNode.up().getKind() == Kind.TYPE_USE) {
+			node = annotationNode.directUp().directUp();
+		} else {
+			node = annotationNode.up();
+		}
+		
+		if (node.getKind() == Kind.FIELD) {
 			// This is meaningless unless the field is used to generate a method (@Setter, @RequiredArgsConstructor, etc),
 			// but in that case those handlers will take care of it. However, we DO check if the annotation is applied to
 			// a primitive, because those handlers trigger on any annotation named @NonNull and we only want the warning
 			// behaviour on _OUR_ 'lombok.NonNull'.
-			EclipseNode fieldNode = annotationNode.up();
+			EclipseNode fieldNode = node;
 			EclipseNode typeNode = fieldNode.up();
 			
 			try {
-				if (isPrimitive(((AbstractVariableDeclaration) annotationNode.up().get()).type)) {
+				if (isPrimitive(((AbstractVariableDeclaration) node.get()).type)) {
 					annotationNode.addWarning("@NonNull is meaningless on a primitive.");
 					return;
 				}
@@ -279,35 +298,21 @@ public class HandleNonNull extends EclipseAnnotationHandler<NonNull> {
 			return;
 		}
 		
+		if (node.getKind() != Kind.ARGUMENT) return;
+		
 		Argument param;
-		EclipseNode paramNode;
 		AbstractMethodDeclaration declaration;
 		
-		switch (annotationNode.up().getKind()) {
-		case ARGUMENT:
-			paramNode = annotationNode.up();
-			break;
-		case TYPE_USE:
-			EclipseNode typeNode = annotationNode.directUp();
-			boolean ok = false;
-			ASTNode astNode = typeNode.get();
-			if (astNode instanceof TypeReference) {
-				Annotation[] anns = EclipseAST.getTopLevelTypeReferenceAnnotations((TypeReference) astNode);
-				if (anns == null) return;
-				for (Annotation ann : anns) if (ast == ann) ok = true;
-			}
-			if (!ok) return;
-			paramNode = typeNode.directUp();
-			break;
-		default:
+		try {
+			param = (Argument) node.get();
+			declaration = (AbstractMethodDeclaration) node.up().get();
+		} catch (Exception e) {
 			return;
 		}
 		
-		try {
-			param = (Argument) paramNode.get();
-			declaration = (AbstractMethodDeclaration) paramNode.up().get();
-		} catch (Exception e) {
-			return;
+		if ((param.modifiers & AccRecord) != 0) {
+			addNullCheckIfNeeded(declaration, param, annotationNode);
+			node.up().rebuild();
 		}
 		
 		if (!force && isGenerated(declaration)) return;
@@ -318,7 +323,7 @@ public class HandleNonNull extends EclipseAnnotationHandler<NonNull> {
 		}
 		
 		addNullCheckIfNeeded(declaration, param, annotationNode);
-		paramNode.up().rebuild();
+		node.up().rebuild();
 	}
 	
 	private void addNullCheckIfNeeded(AbstractMethodDeclaration declaration, AbstractVariableDeclaration param, EclipseNode annotationNode) {
