@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2009-2020 The Project Lombok Authors.
+ * Copyright (C) 2009-2025 The Project Lombok Authors.
  * 
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -41,6 +41,7 @@ import lombok.core.CleanupRegistry;
 import lombok.core.CleanupTask;
 import lombok.permit.Permit;
 
+import com.sun.tools.javac.code.Lint.LintCategory;
 import com.sun.tools.javac.code.Source;
 import com.sun.tools.javac.code.Symtab;
 import com.sun.tools.javac.model.JavacElements;
@@ -415,7 +416,6 @@ public class JavacAST extends AST<JavacAST, JavacNode, JCTree> {
 		JCANNOTATEDTYPE_FIELDS_INITIALIZED = true;
 	}
 	
-	
 	private static Field JCENHANCEDFORLOOP_VARORRECORDPATTERN_FIELD = Permit.permissiveGetField(JCEnhancedForLoop.class, "varOrRecordPattern");
 	private static JCTree getVarOrRecordPattern(JCEnhancedForLoop loop) {
 		if (JCENHANCEDFORLOOP_VARORRECORDPATTERN_FIELD == null) {
@@ -581,9 +581,6 @@ public class JavacAST extends AST<JavacAST, JavacNode, JCTree> {
 			case ERROR:
 				errorLogger.error(pos, message);
 				break;
-			case MANDATORY_WARNING:
-				errorLogger.mandatoryWarning(pos, message);
-				break;
 			case WARNING:
 				errorLogger.warning(pos, message);
 				break;
@@ -596,7 +593,7 @@ public class JavacAST extends AST<JavacAST, JavacNode, JCTree> {
 			if (newSource != null) errorLogger.useSource(oldSource);
 		}
 	}
-
+	
 	public void removeFromDeferredDiagnostics(int startPos, int endPos) {
 		JCCompilationUnit self = (JCCompilationUnit) top().get();
 		new CompilerMessageSuppressor(getContext()).removeAllBetween(self.sourcefile, startPos, endPos);
@@ -643,29 +640,23 @@ public class JavacAST extends AST<JavacAST, JavacNode, JCTree> {
 			this.errorCount = errorCount;
 			this.warningCount = warningCount;
 		}
-
+		
 		final JavaFileObject useSource(JavaFileObject file) {
 			return log.useSource(file);
 		}
-
+		
 		final void error(DiagnosticPosition pos, String message) {
 			increment(errorCount);
 			error1(pos, message);
 		}
-
+		
 		final void warning(DiagnosticPosition pos, String message) {
 			increment(warningCount);
 			warning1(pos, message);
 		}
-
-		final void mandatoryWarning(DiagnosticPosition pos, String message) {
-			increment(warningCount);
-			mandatoryWarning1(pos, message);
-		}
-
+		
 		abstract void error1(DiagnosticPosition pos, String message);
 		abstract void warning1(DiagnosticPosition pos, String message);
-		abstract void mandatoryWarning1(DiagnosticPosition pos, String message);
 		abstract void note(DiagnosticPosition pos, String message);
 		
 		private void increment(Field field) {
@@ -689,7 +680,6 @@ public class JavacAST extends AST<JavacAST, JavacNode, JCTree> {
 			for (Field field : log.getClass().getFields()) {
 				if (field.getName().equals("multipleErrors")) {
 					hasMultipleErrors = true;
-					break;
 				}
 			}
 			if (hasMultipleErrors) return new JdkBefore9(log, messager, errorCount);
@@ -708,7 +698,7 @@ public class JavacAST extends AST<JavacAST, JavacNode, JCTree> {
 		private JdkBefore9(Log log, Messager messager, Field errorCount) {
 			super(log, messager, errorCount, null);
 		}
-
+		
 		@Override void error1(DiagnosticPosition pos, String message) {
 			boolean prev = log.multipleErrors;
 			log.multipleErrors = true;
@@ -718,15 +708,11 @@ public class JavacAST extends AST<JavacAST, JavacNode, JCTree> {
 				log.multipleErrors = prev;
 			}
 		}
-
+		
 		@Override void warning1(DiagnosticPosition pos, String message) {
 			log.warning(pos, "proc.messager", message);
 		}
-
-		@Override void mandatoryWarning1(DiagnosticPosition pos, String message) {
-			log.mandatoryWarning(pos, "proc.messager", message);
-		}
-
+		
 		@Override void note(DiagnosticPosition pos, String message) {
 			log.note(pos, "proc.messager", message);
 		}
@@ -735,20 +721,20 @@ public class JavacAST extends AST<JavacAST, JavacNode, JCTree> {
 	static class Jdk9Plus extends ErrorLog {
 		private static final String PROC_MESSAGER = "proc.messager";
 		private Object multiple;
-		private Method errorMethod, warningMethod, mandatoryWarningMethod, noteMethod;
+		private Method errorMethod, warningMethod, noteMethod;
 		private Method errorKey, warningKey, noteKey;
 		private JCDiagnostic.Factory diags;
 		
 		private Jdk9Plus(Log log, Messager messager, Field errorCount, Field warningCount) {
 			super(log, messager, errorCount, warningCount);
-
+			
 			try {
 				final String jcd = "com.sun.tools.javac.util.JCDiagnostic";
 				Class<?> df = Class.forName(jcd + "$DiagnosticFlag");
 				for (Object constant : df.getEnumConstants()) {
 					if (constant.toString().equals("MULTIPLE")) this.multiple = constant;
 				}
-
+				
 				Class<?> errorCls = Class.forName(jcd + "$Error");
 				Class<?> warningCls = Class.forName(jcd + "$Warning");
 				Class<?> noteCls = Class.forName(jcd + "$Note");
@@ -756,15 +742,17 @@ public class JavacAST extends AST<JavacAST, JavacNode, JCTree> {
 				Class<?> lc = log.getClass();
 				this.errorMethod = Permit.getMethod(lc, "error", df, DiagnosticPosition.class, errorCls);
 				this.warningMethod = Permit.getMethod(lc, "warning", DiagnosticPosition.class, warningCls);
-				this.mandatoryWarningMethod = Permit.getMethod(lc, "mandatoryWarning", DiagnosticPosition.class, warningCls);
 				this.noteMethod = Permit.getMethod(lc, "note", DiagnosticPosition.class, noteCls);
-
+				
 				Field diagsField = Permit.getField(lc.getSuperclass(), "diags");
 				this.diags = (JCDiagnostic.Factory) diagsField.get(log);
-
+				
 				Class<?> dc = this.diags.getClass();
 				this.errorKey = Permit.getMethod(dc, "errorKey", String.class, Object[].class);
-				this.warningKey = Permit.getMethod(dc, "warningKey", String.class, Object[].class);
+				this.warningKey = Permit.permissiveGetMethod(dc, "warningKey", String.class, Object[].class);
+				if (warningKey == null) {
+					this.warningKey = Permit.getMethod(dc, "warningKey", LintCategory.class, String.class, Object[].class);
+				}
 				this.noteKey = Permit.getMethod(dc, "noteKey", String.class, Object[].class);
 			} catch (Throwable t) {
 				//t.printStackTrace();
@@ -775,19 +763,18 @@ public class JavacAST extends AST<JavacAST, JavacNode, JCTree> {
 			Object error = Permit.invokeSneaky(this.errorKey, diags, PROC_MESSAGER, new Object[] { message });
 			if (error != null) Permit.invokeSneaky(errorMethod, log, multiple, pos, error);
 		}
-
+		
 		@Override
 		void warning1(DiagnosticPosition pos, String message) {
-			Object warning = Permit.invokeSneaky(this.warningKey, diags, PROC_MESSAGER, new Object[] { message });
+			Object warning;
+			if (this.warningKey.getParameterTypes().length == 3) {
+				warning = Permit.invokeSneaky(this.warningKey, diags, null, PROC_MESSAGER, new Object[] { message });
+			} else {
+				warning = Permit.invokeSneaky(this.warningKey, diags, PROC_MESSAGER, new Object[] { message });
+			}
 			if (warning != null) Permit.invokeSneaky(warningMethod, log, pos, warning);
 		}
-
-		@Override
-		void mandatoryWarning1(DiagnosticPosition pos, String message) {
-			Object warning = Permit.invokeSneaky(this.warningKey, diags, PROC_MESSAGER, new Object[] { message });
-			if (warning != null) Permit.invokeSneaky(mandatoryWarningMethod, log, pos, warning);
-		}
-
+		
 		@Override
 		void note(DiagnosticPosition pos, String message) {
 			Object note = Permit.invokeSneaky(this.noteKey, diags, PROC_MESSAGER, new Object[] { message });
