@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2013-2021 The Project Lombok Authors.
+ * Copyright (C) 2013-2025 The Project Lombok Authors.
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -36,6 +36,7 @@ import com.sun.tools.javac.code.BoundKind;
 import com.sun.tools.javac.code.Flags;
 import com.sun.tools.javac.tree.JCTree;
 import com.sun.tools.javac.tree.JCTree.JCAnnotation;
+import com.sun.tools.javac.tree.JCTree.JCArrayTypeTree;
 import com.sun.tools.javac.tree.JCTree.JCAssign;
 import com.sun.tools.javac.tree.JCTree.JCBlock;
 import com.sun.tools.javac.tree.JCTree.JCClassDecl;
@@ -63,9 +64,9 @@ import lombok.ConfigurationKeys;
 import lombok.Singular;
 import lombok.ToString;
 import lombok.core.AST.Kind;
-import lombok.core.configuration.CheckerFrameworkVersion;
 import lombok.core.AnnotationValues;
 import lombok.core.HandlerPriority;
+import lombok.core.configuration.CheckerFrameworkVersion;
 import lombok.core.handlers.HandlerUtil;
 import lombok.core.handlers.HandlerUtil.FieldAccess;
 import lombok.core.handlers.InclusionExclusionUtils.Included;
@@ -77,6 +78,8 @@ import lombok.javac.JavacNode;
 import lombok.javac.JavacTreeMaker;
 import lombok.javac.handlers.HandleBuilder.BuilderFieldData;
 import lombok.javac.handlers.HandleBuilder.BuilderJob;
+import lombok.javac.handlers.JavacHandlerUtil.CopyJavadoc;
+import lombok.javac.handlers.JavacHandlerUtil.JCAnnotatedTypeReflect;
 import lombok.javac.handlers.JavacHandlerUtil.MemberExistsResult;
 import lombok.javac.handlers.JavacSingularsRecipes.ExpressionMaker;
 import lombok.javac.handlers.JavacSingularsRecipes.JavacSingularizer;
@@ -140,13 +143,10 @@ public class HandleSuperBuilder extends JavacAnnotationHandler<SuperBuilder> {
 		job.init(annotation, annInstance, annotationNode);
 		
 		boolean generateBuilderMethod;
-		if (job.builderMethodName.isEmpty()) {
-			generateBuilderMethod = false;
-		} else if (!checkName("builderMethodName", job.builderMethodName, annotationNode)) {
-			return;
-		} else {
-			generateBuilderMethod = true;
-		}
+		if (job.builderMethodName.isEmpty()) generateBuilderMethod = false;
+		else if (!checkName("builderMethodName", job.builderMethodName, annotationNode)) return;
+		else generateBuilderMethod = true;
+		
 		if (!checkName("buildMethodName", job.buildMethodName, annotationNode)) return;
 		
 		// Do not delete the SuperBuilder annotation here, we need it for @Jacksonized.
@@ -260,7 +260,7 @@ public class HandleSuperBuilder extends JavacAnnotationHandler<SuperBuilder> {
 			Name superclassName = ((JCFieldAccess) extendsClause).getIdentifier();
 			String builderClassNameTemplate = BuilderJob.getBuilderClassNameTemplate(annotationNode, null);
 			String superclassBuilderClassName = job.replaceBuilderClassName(superclassName.toString(), builderClassNameTemplate);
-			superclassBuilderClass = parent.getTreeMaker().Select((JCFieldAccess) extendsClause, parent.toName(superclassBuilderClassName));
+			superclassBuilderClass = parent.getTreeMaker().Select(cloneType(maker, (JCFieldAccess) extendsClause, annotationNode), parent.toName(superclassBuilderClassName));
 		} else if (extendsClause != null) {
 			String builderClassNameTemplate = BuilderJob.getBuilderClassNameTemplate(annotationNode, null);
 			String superclassBuilderClassName = job.replaceBuilderClassName(extendsClause.toString(), builderClassNameTemplate);
@@ -310,9 +310,7 @@ public class HandleSuperBuilder extends JavacAnnotationHandler<SuperBuilder> {
 				if (sd == null) continue;
 				JavacSingularizer singularizer = sd.getSingularizer();
 				if (singularizer == null) continue;
-				if (singularizer.checkForAlreadyExistingNodesAndGenerateError(job.builderAbstractType, sd)) {
-					bfd.singularData = null;
-				}
+				if (singularizer.checkForAlreadyExistingNodesAndGenerateError(job.builderAbstractType, sd)) bfd.singularData = null;
 			}
 		}
 		
@@ -336,6 +334,11 @@ public class HandleSuperBuilder extends JavacAnnotationHandler<SuperBuilder> {
 			injectMethod(job.builderType, sfvm);
 		}
 		
+		// Create the setter methods in the abstract builder.
+		for (BuilderFieldData bfd : job.builderFields) {
+			generateSetterMethodsForBuilder(job, bfd, builderGenericName, annInstance.setterPrefix());
+		}
+		
 		// Generate abstract self() and build() methods in the abstract builder.
 		JCMethodDecl asm = generateAbstractSelfMethod(job, superclassBuilderClass != null, builderGenericName);
 		recursiveSetGeneratedBy(asm, annotationNode);
@@ -344,11 +347,6 @@ public class HandleSuperBuilder extends JavacAnnotationHandler<SuperBuilder> {
 		recursiveSetGeneratedBy(abm, annotationNode);
 		injectMethod(job.builderType, abm);
 		
-		// Create the setter methods in the abstract builder.
-		for (BuilderFieldData bfd : job.builderFields) {
-			generateSetterMethodsForBuilder(job, bfd, builderGenericName, annInstance.setterPrefix());
-		}
-		
 		// Create the toString() method for the abstract builder.
 		java.util.List<Included<JavacNode, ToString.Include>> fieldNodes = new ArrayList<Included<JavacNode, ToString.Include>>();
 		for (BuilderFieldData bfd : job.builderFields) {
@@ -386,7 +384,7 @@ public class HandleSuperBuilder extends JavacAnnotationHandler<SuperBuilder> {
 				}
 				sanityCheckForMethodGeneratingAnnotationsOnBuilderClass(job.builderImplType, annotationNode);
 			}
-
+			
 			// Create a simple constructor for the BuilderImpl class.
 			JCMethodDecl cd = HandleConstructor.createConstructor(AccessLevel.PRIVATE, List.<JCAnnotation>nil(), job.builderImplType, List.<JavacNode>nil(), false, annotationNode);
 			if (cd != null) injectMethod(job.builderImplType, cd);
@@ -512,7 +510,7 @@ public class HandleSuperBuilder extends JavacAnnotationHandler<SuperBuilder> {
 		recursiveSetGeneratedBy(builder, job.sourceNode);
 		return injectType(job.parentType, builder);
 	}
-
+	
 	/**
 	 * Generates a constructor that has a builder as the only parameter.
 	 * The values from the builder are used to initialize the fields of new instances.
@@ -579,8 +577,8 @@ public class HandleSuperBuilder extends JavacAnnotationHandler<SuperBuilder> {
 		if (callBuilderBasedSuperConstructor) {
 			// The first statement must be the call to the super constructor.
 			JCMethodInvocation callToSuperConstructor = maker.Apply(List.<JCExpression>nil(),
-					maker.Ident(job.toName("super")),
-					List.<JCExpression>of(maker.Ident(builderVariableName)));
+				maker.Ident(job.toName("super")),
+				List.<JCExpression>of(maker.Ident(builderVariableName)));
 			statements.prepend(maker.Exec(callToSuperConstructor));
 		}
 		
@@ -607,6 +605,7 @@ public class HandleSuperBuilder extends JavacAnnotationHandler<SuperBuilder> {
 		// Now add the <?, ?>.
 		JCWildcard wildcard = maker.Wildcard(maker.TypeBoundKind(BoundKind.UNBOUND), null);
 		typeParameterNames.append(wildcard);
+		wildcard = maker.Wildcard(maker.TypeBoundKind(BoundKind.UNBOUND), null);
 		typeParameterNames.append(wildcard);
 		// And return type annotations.
 		List<JCAnnotation> annsOnParamType = List.nil();
@@ -620,7 +619,9 @@ public class HandleSuperBuilder extends JavacAnnotationHandler<SuperBuilder> {
 	}
 	
 	/**
-	 * Generates a <code>toBuilder()</code> method in the annotated class that looks like this:
+	 * Generates a {@code toBuilder()} method in the annotated class.
+	 * 
+	 * It looks like:
 	 * <pre>
 	 * public ParentBuilder&lt;?, ?&gt; toBuilder() {
 	 *     return new <i>Foobar</i>BuilderImpl().$fillValuesFrom(this);
@@ -644,6 +645,7 @@ public class HandleSuperBuilder extends JavacAnnotationHandler<SuperBuilder> {
 		// Now add the <?, ?>.
 		JCWildcard wildcard = maker.Wildcard(maker.TypeBoundKind(BoundKind.UNBOUND), null);
 		typeParameterNames.append(wildcard);
+		wildcard = maker.Wildcard(maker.TypeBoundKind(BoundKind.UNBOUND), null);
 		typeParameterNames.append(wildcard);
 		JCTypeApply returnType = maker.TypeApply(namePlusTypeParamsToTypeReference(maker, job.parentType, job.toName(job.builderAbstractClassName), false, List.<JCTypeParameter>nil()), typeParameterNames.toList());
 		
@@ -652,10 +654,11 @@ public class HandleSuperBuilder extends JavacAnnotationHandler<SuperBuilder> {
 		createRelevantNonNullAnnotation(job.parentType, methodDef);
 		return methodDef;
 	}
-
+	
 	/**
-	 * Generates a <code>$fillValuesFrom()</code> method in the abstract builder class that looks
-	 * like this:
+	 * Generates a {@code $fillValuesFrom()} method in the abstract builder class.
+	 * 
+	 * It looks like:
 	 * <pre>
 	 * protected B $fillValuesFrom(final C instance) {
 	 *     super.$fillValuesFrom(instance);
@@ -677,7 +680,7 @@ public class HandleSuperBuilder extends JavacAnnotationHandler<SuperBuilder> {
 		
 		JCExpression classGenericNameExpr = maker.Ident(job.toName(classGenericName));
 		JCVariableDecl param = maker.VarDef(maker.Modifiers(Flags.PARAMETER | Flags.FINAL), job.toName(INSTANCE_VARIABLE_NAME), classGenericNameExpr, null);
-
+		
 		ListBuffer<JCStatement> body = new ListBuffer<JCStatement>();
 		
 		if (inherited) {
@@ -701,11 +704,12 @@ public class HandleSuperBuilder extends JavacAnnotationHandler<SuperBuilder> {
 		
 		return maker.MethodDef(modifiers, name, returnType, List.<JCTypeParameter>nil(), List.of(param), List.<JCExpression>nil(), bodyBlock, null);
 	}
-
+	
 	/**
-	 * Generates a <code>$fillValuesFromInstanceIntoBuilder()</code> method in
+	 * Generates a {@code $fillValuesFromInstanceIntoBuilder()} method in
 	 * the builder implementation class that copies all fields from the instance
-	 * to the builder. It looks like this:
+	 * to the builder.
+	 * It looks like:
 	 * 
 	 * <pre>
 	 * protected B $fillValuesFromInstanceIntoBuilder(Foobar instance, FoobarBuilder&lt;?, ?&gt; b) {
@@ -722,7 +726,7 @@ public class HandleSuperBuilder extends JavacAnnotationHandler<SuperBuilder> {
 		
 		// 1st parameter: "Foobar instance"
 		JCVariableDecl paramInstance = maker.VarDef(maker.Modifiers(Flags.PARAMETER | Flags.FINAL), job.toName(INSTANCE_VARIABLE_NAME), cloneSelfType(job.parentType), null);
-
+		
 		// 2nd parameter: "FoobarBuilder<?, ?> b" (plus generics on the annotated type)
 		// First add all generics that are present on the parent type.
 		ListBuffer<JCExpression> typeParamsForBuilderParameter = getTypeParamExpressions(job.typeParams, maker, job.sourceNode);
@@ -795,7 +799,7 @@ public class HandleSuperBuilder extends JavacAnnotationHandler<SuperBuilder> {
 		Name name = job.toName(SELF_METHOD);
 		JCExpression returnType = maker.Ident(job.toName(builderGenericName));
 		returnType = addCheckerFrameworkReturnsReceiver(returnType, maker, job.builderType, job.checkerFramework);
-
+		
 		return maker.MethodDef(modifiers, name, returnType, List.<JCTypeParameter>nil(), List.<JCVariableDecl>nil(), List.<JCExpression>nil(), null, null);
 	}
 	
@@ -960,10 +964,15 @@ public class HandleSuperBuilder extends JavacAnnotationHandler<SuperBuilder> {
 		
 		JavacTreeMaker maker = fieldNode.getTreeMaker();
 		
-		List<JCAnnotation> methodAnns = JavacHandlerUtil.findCopyableToSetterAnnotations(originalFieldNode);
+		List<JCAnnotation> methodAnns = JavacHandlerUtil.findCopyableToSetterAnnotations(originalFieldNode, true);
 		returnType = addCheckerFrameworkReturnsReceiver(returnType, maker, job.builderType, job.checkerFramework);
 
 		JCMethodDecl newMethod = HandleSetter.createSetter(Flags.PUBLIC, deprecate, fieldNode, maker, setterName, paramName, nameOfSetFlag, returnType, returnStatement, job.sourceNode, methodAnns, annosOnParam);
+		if (job.sourceNode.up().getKind() == Kind.METHOD) {
+			copyJavadocFromParam(originalFieldNode.up(), newMethod, paramName.toString());
+		} else {
+			copyJavadoc(originalFieldNode, newMethod, CopyJavadoc.SETTER, true);
+		}
 		injectMethod(job.builderType, newMethod);
 	}
 	
@@ -1036,8 +1045,7 @@ public class HandleSuperBuilder extends JavacAnnotationHandler<SuperBuilder> {
 		java.util.HashSet<String> usedNames = new HashSet<String>();
 		
 		// 1. Add type parameter names.
-		for (JCTypeParameter typeParam : typeParams)
-			usedNames.add(typeParam.getName().toString());
+		for (JCTypeParameter typeParam : typeParams) usedNames.add(typeParam.getName().toString());
 		
 		// 2. Add class name.
 		usedNames.add(td.name.toString());
@@ -1046,14 +1054,30 @@ public class HandleSuperBuilder extends JavacAnnotationHandler<SuperBuilder> {
 		for (JCTree member : td.getMembers()) {
 			if (member.getKind() == com.sun.source.tree.Tree.Kind.VARIABLE && member instanceof JCVariableDecl) {
 				JCTree type = ((JCVariableDecl)member).getType();
-				if (type instanceof JCIdent)
-					usedNames.add(((JCIdent)type).getName().toString());
+				if (type instanceof JCIdent) usedNames.add(((JCIdent)type).getName().toString());
 			}
 		}
 		
+		// 4. Add extends and implements clauses.
+		addFirstToken(usedNames, Javac.getExtendsClause(td));
+		for (JCExpression impl : td.getImplementsClause()) addFirstToken(usedNames, impl);
+		
 		return usedNames;
 	}
 	
+	private void addFirstToken(java.util.Set<String> usedNames, JCTree type) {
+		if (type == null) 
+			return;
+		if (type instanceof JCTypeApply) {
+			type = ((JCTypeApply)type).clazz;
+		}
+		while (type instanceof JCFieldAccess && ((JCFieldAccess)type).selected != null) {
+			// Add the first token, because only that can collide.
+			type = ((JCFieldAccess) type).selected;
+		}
+		usedNames.add(type.toString());
+	}
+	
 	private String generateNonclashingNameFor(String classGenericName, java.util.HashSet<String> typeParamStrings) {
 		if (!typeParamStrings.contains(classGenericName)) return classGenericName;
 		int counter = 2;
@@ -1074,18 +1098,22 @@ public class HandleSuperBuilder extends JavacAnnotationHandler<SuperBuilder> {
 		ListBuffer<JCExpression> typeParamsForBuilderParameter = new ListBuffer<JCExpression>();
 		for (JCTree typeParam : typeParams) {
 			if (typeParam instanceof JCTypeParameter) {
-				typeParamsForBuilderParameter.append(maker.Ident(((JCTypeParameter)typeParam).getName()));
+				typeParamsForBuilderParameter.append(maker.Ident(((JCTypeParameter) typeParam).getName()));
 			} else if (typeParam instanceof JCIdent) {
-				typeParamsForBuilderParameter.append(maker.Ident(((JCIdent)typeParam).getName()));
+				typeParamsForBuilderParameter.append(maker.Ident(((JCIdent) typeParam).getName()));
 			} else if (typeParam instanceof JCFieldAccess) {
 				typeParamsForBuilderParameter.append(copySelect(maker, (JCFieldAccess) typeParam));
 			} else if (typeParam instanceof JCTypeApply) {
-				typeParamsForBuilderParameter.append(cloneType(maker, (JCTypeApply)typeParam, source));
+				typeParamsForBuilderParameter.append(cloneType(maker, (JCTypeApply) typeParam, source));
+			} else if (typeParam instanceof JCArrayTypeTree) {
+				typeParamsForBuilderParameter.append(cloneType(maker, (JCArrayTypeTree) typeParam, source));
+			} else if (JCAnnotatedTypeReflect.is(typeParam)) {
+				typeParamsForBuilderParameter.append(cloneType(maker, (JCExpression) typeParam, source));
 			}
 		}
 		return typeParamsForBuilderParameter;
 	}
-
+	
 	private JCExpression copySelect(JavacTreeMaker maker, JCFieldAccess typeParam) {
 		java.util.List<Name> chainNames = new ArrayList<Name>();
 		JCExpression expression = typeParam;
@@ -1098,7 +1126,7 @@ public class HandleSuperBuilder extends JavacAnnotationHandler<SuperBuilder> {
 				expression = null;
 			}
 		}
-
+		
 		Collections.reverse(chainNames);
 		JCExpression typeParameter = null;
 		for (Name name : chainNames) {
@@ -1121,18 +1149,16 @@ public class HandleSuperBuilder extends JavacAnnotationHandler<SuperBuilder> {
 					JCMethodDecl md = (JCMethodDecl) def;
 					String name = md.name.toString();
 					boolean matches = name.equals("<init>");
-					if (isTolerate(type, md)) 
-						continue;
+					if (isTolerate(type, md)) continue;
 					if (matches && md.params != null && md.params.length() == 1) {
 						// Cannot use typeMatches() here, because the parameter could be fully-qualified, partially-qualified, or not qualified.
 						// A string-compare of the last part should work. If it's a false-positive, users could still @Tolerate it.
 						String typeName = md.params.get(0).getType().toString();
 						int lastIndexOfDot = typeName.lastIndexOf('.');
 						if (lastIndexOfDot >= 0) {
-							typeName = typeName.substring(lastIndexOfDot+1);
+							typeName = typeName.substring(lastIndexOfDot + 1);
 						}
-						if ((builderClassName+"<?, ?>").equals(typeName))
-							return true;
+						if ((builderClassName+"<?, ?>").equals(typeName)) return true;
 					}
 				}
 			}
