@@ -23,17 +23,18 @@ module lombok {
 	requires java.compiler;
 	requires java.instrument;
 	requires jdk.unsupported;
-	requires static org.mapstruct.processor;
 	
 	exports lombok;
 	exports lombok.experimental;
 	exports lombok.extern.apachecommons;
+	exports lombok.extern.flogger;
+	exports lombok.extern.jackson;
 	exports lombok.extern.java;
 	exports lombok.extern.jbosslog;
 	exports lombok.extern.log4j;
 	exports lombok.extern.slf4j;
-	exports lombok.extern.flogger;
+	
+	exports lombok.launch to lombok.mapstruct;
 	
 	provides javax.annotation.processing.Processor with lombok.launch.AnnotationProcessorHider.AnnotationProcessor;
-	provides org.mapstruct.ap.spi.AstModifyingAnnotationProcessor with lombok.launch.AnnotationProcessorHider.AstModificationNotifier;
 }
