@@ -1,5 +1,7 @@
 package com.sun.tools.javac.parser;
 
+import com.sun.tools.javac.util.JCDiagnostic;
+
 public class Tokens {
 	public static class Token {
 		public int pos;
@@ -12,6 +14,10 @@ public class Tokens {
 		
 		String getText();
 		
+		Comment stripIndent();
+		
+		JCDiagnostic.DiagnosticPosition getPos();
+		
 		int getSourcePos(int index);
 		
 		CommentStyle getStyle();
