@@ -6,6 +6,7 @@ class GetterLazyBoolean {
 	}
 	@java.lang.Override
 	@java.lang.SuppressWarnings("all")
+	@lombok.Generated
 	public boolean equals(final java.lang.Object o) {
 		if (o == this) return true;
 		if (!(o instanceof GetterLazyBoolean)) return false;
@@ -15,11 +16,13 @@ class GetterLazyBoolean {
 		return true;
 	}
 	@java.lang.SuppressWarnings("all")
+	@lombok.Generated
 	protected boolean canEqual(final java.lang.Object other) {
 		return other instanceof GetterLazyBoolean;
 	}
 	@java.lang.Override
 	@java.lang.SuppressWarnings("all")
+	@lombok.Generated
 	public int hashCode() {
 		final int PRIME = 59;
 		int result = 1;
@@ -28,37 +31,40 @@ class GetterLazyBoolean {
 	}
 	@java.lang.Override
 	@java.lang.SuppressWarnings("all")
+	@lombok.Generated
 	public java.lang.String toString() {
 		return "GetterLazyBoolean(booleanValue=" + this.isBooleanValue() + ")";
 	}
 	@java.lang.SuppressWarnings({"all", "unchecked"})
+	@lombok.Generated
 	public boolean isBooleanValue() {
-		java.lang.Object value = this.booleanValue.get();
-		if (value == null) {
+		java.lang.Object $value = this.booleanValue.get();
+		if ($value == null) {
 			synchronized (this.booleanValue) {
-				value = this.booleanValue.get();
-				if (value == null) {
+				$value = this.booleanValue.get();
+				if ($value == null) {
 					final boolean actualValue = calculateBoolean();
-					value = actualValue;
-					this.booleanValue.set(value);
+					$value = actualValue;
+					this.booleanValue.set($value);
 				}
 			}
 		}
-		return (java.lang.Boolean) value;
+		return (java.lang.Boolean) $value;
 	}
 	@java.lang.SuppressWarnings({"all", "unchecked"})
+	@lombok.Generated
 	public boolean isOtherBooleanValue() {
-		java.lang.Object value = this.otherBooleanValue.get();
-		if (value == null) {
+		java.lang.Object $value = this.otherBooleanValue.get();
+		if ($value == null) {
 			synchronized (this.otherBooleanValue) {
-				value = this.otherBooleanValue.get();
-				if (value == null) {
+				$value = this.otherBooleanValue.get();
+				if ($value == null) {
 					final boolean actualValue = !calculateBoolean();
-					value = actualValue;
-					this.otherBooleanValue.set(value);
+					$value = actualValue;
+					this.otherBooleanValue.set($value);
 				}
 			}
 		}
-		return (java.lang.Boolean) value;
+		return (java.lang.Boolean) $value;
 	}
 }
