@@ -1,10 +1,9 @@
 class GetterLazyEahcToString {
-	
 	private final java.util.concurrent.atomic.AtomicReference<java.lang.Object> value = new java.util.concurrent.atomic.AtomicReference<java.lang.Object>();
 	private final String value2 = "";
-	
 	@java.lang.Override
 	@java.lang.SuppressWarnings("all")
+	@lombok.Generated
 	public boolean equals(final java.lang.Object o) {
 		if (o == this) return true;
 		if (!(o instanceof GetterLazyEahcToString)) return false;
@@ -18,16 +17,14 @@ class GetterLazyEahcToString {
 		if (this$value2 == null ? other$value2 != null : !this$value2.equals(other$value2)) return false;
 		return true;
 	}
-	
 	@java.lang.SuppressWarnings("all")
-	
-	
+	@lombok.Generated
 	protected boolean canEqual(final java.lang.Object other) {
 		return other instanceof GetterLazyEahcToString;
 	}
-	
 	@java.lang.Override
 	@java.lang.SuppressWarnings("all")
+	@lombok.Generated
 	public int hashCode() {
 		final int PRIME = 59;
 		int result = 1;
@@ -37,30 +34,30 @@ class GetterLazyEahcToString {
 		result = result * PRIME + ($value2 == null ? 43 : $value2.hashCode());
 		return result;
 	}
-	
 	@java.lang.Override
 	@java.lang.SuppressWarnings("all")
+	@lombok.Generated
 	public java.lang.String toString() {
 		return "GetterLazyEahcToString(value=" + this.getValue() + ", value2=" + this.value2 + ")";
 	}
-	
 	@java.lang.SuppressWarnings({"all", "unchecked"})
+	@lombok.Generated
 	public String getValue() {
-		java.lang.Object value = this.value.get();
-		if (value == null) {
+		java.lang.Object $value = this.value.get();
+		if ($value == null) {
 			synchronized (this.value) {
-				value = this.value.get();
-				if (value == null) {
+				$value = this.value.get();
+				if ($value == null) {
 					final String actualValue = "";
-					value = actualValue == null ? this.value : actualValue;
-					this.value.set(value);
+					$value = actualValue == null ? this.value : actualValue;
+					this.value.set($value);
 				}
 			}
 		}
-		return (String) (value == this.value ? null : value);
+		return (String) ($value == this.value ? null : $value);
 	}
-	
 	@java.lang.SuppressWarnings("all")
+	@lombok.Generated
 	public String getValue2() {
 		return this.value2;
 	}
