@@ -3,21 +3,23 @@ class GetterLazyTransient {
 	private final transient int transientField = 2;
 	private final transient int nonLazyTransientField = 3;
 	@java.lang.SuppressWarnings({"all", "unchecked"})
+	@lombok.Generated
 	public int getNonTransientField() {
-		java.lang.Object value = this.nonTransientField.get();
-		if (value == null) {
+		java.lang.Object $value = this.nonTransientField.get();
+		if ($value == null) {
 			synchronized (this.nonTransientField) {
-				value = this.nonTransientField.get();
-				if (value == null) {
+				$value = this.nonTransientField.get();
+				if ($value == null) {
 					final int actualValue = 1;
-					value = actualValue;
-					this.nonTransientField.set(value);
+					$value = actualValue;
+					this.nonTransientField.set($value);
 				}
 			}
 		}
-		return (java.lang.Integer) value;
+		return (java.lang.Integer) $value;
 	}
 	@java.lang.SuppressWarnings("all")
+	@lombok.Generated
 	public int getNonLazyTransientField() {
 		return this.nonLazyTransientField;
 	}
