@@ -1,4 +1,7 @@
 // version 8:
+import java.util.function.Function;
+import java.util.function.Supplier;
+
 class ValInLambda {
     Runnable foo = (Runnable) () -> {
         final int i = 1;
@@ -24,4 +27,12 @@ class ValInLambda {
             } : System.out::println;
         };
     }
+
+    public void inParameter() {
+        final java.util.function.Function<java.util.function.Supplier<java.lang.String>, java.lang.String> foo = (Function<Supplier<String>, String>) s -> s.get();
+        final java.lang.String foo2 = foo.apply(() -> {
+            final java.lang.String bar = "";
+            return bar;
+        });
+    }
 }
