@@ -2,21 +2,21 @@ import java.util.Set;
 import java.util.SortedSet;
 import lombok.Singular;
 @lombok.Builder class BuilderSingularSets<T> {
-  public static @java.lang.SuppressWarnings("all") class BuilderSingularSetsBuilder<T> {
-    private @java.lang.SuppressWarnings("all") java.util.ArrayList<T> dangerMice;
-    private @java.lang.SuppressWarnings("all") java.util.ArrayList<Number> octopodes;
-    private @java.lang.SuppressWarnings("all") java.util.ArrayList<java.lang.Object> rawSet;
-    private @java.lang.SuppressWarnings("all") java.util.ArrayList<String> stringSet;
-    @java.lang.SuppressWarnings("all") BuilderSingularSetsBuilder() {
+  public static @java.lang.SuppressWarnings("all") @lombok.Generated class BuilderSingularSetsBuilder<T> {
+    private @java.lang.SuppressWarnings("all") @lombok.Generated java.util.ArrayList<T> dangerMice;
+    private @java.lang.SuppressWarnings("all") @lombok.Generated java.util.ArrayList<Number> octopodes;
+    private @java.lang.SuppressWarnings("all") @lombok.Generated java.util.ArrayList<java.lang.Object> rawSet;
+    private @java.lang.SuppressWarnings("all") @lombok.Generated java.util.ArrayList<String> stringSet;
+    @java.lang.SuppressWarnings("all") @lombok.Generated BuilderSingularSetsBuilder() {
       super();
     }
-    public @java.lang.SuppressWarnings("all") BuilderSingularSets.BuilderSingularSetsBuilder<T> dangerMouse(final T dangerMouse) {
+    public @java.lang.SuppressWarnings("all") @lombok.Generated BuilderSingularSets.BuilderSingularSetsBuilder<T> dangerMouse(final T dangerMouse) {
       if ((this.dangerMice == null))
           this.dangerMice = new java.util.ArrayList<T>();
       this.dangerMice.add(dangerMouse);
       return this;
     }
-    public @java.lang.SuppressWarnings("all") BuilderSingularSets.BuilderSingularSetsBuilder<T> dangerMice(final java.util.Collection<? extends T> dangerMice) {
+    public @java.lang.SuppressWarnings("all") @lombok.Generated BuilderSingularSets.BuilderSingularSetsBuilder<T> dangerMice(final java.util.Collection<? extends T> dangerMice) {
       if ((dangerMice == null))
           {
             throw new java.lang.NullPointerException("dangerMice cannot be null");
@@ -26,18 +26,18 @@ import lombok.Singular;
       this.dangerMice.addAll(dangerMice);
       return this;
     }
-    public @java.lang.SuppressWarnings("all") BuilderSingularSets.BuilderSingularSetsBuilder<T> clearDangerMice() {
+    public @java.lang.SuppressWarnings("all") @lombok.Generated BuilderSingularSets.BuilderSingularSetsBuilder<T> clearDangerMice() {
       if ((this.dangerMice != null))
           this.dangerMice.clear();
       return this;
     }
-    public @java.lang.SuppressWarnings("all") BuilderSingularSets.BuilderSingularSetsBuilder<T> octopus(final Number octopus) {
+    public @java.lang.SuppressWarnings("all") @lombok.Generated BuilderSingularSets.BuilderSingularSetsBuilder<T> octopus(final Number octopus) {
       if ((this.octopodes == null))
           this.octopodes = new java.util.ArrayList<Number>();
       this.octopodes.add(octopus);
       return this;
     }
-    public @java.lang.SuppressWarnings("all") BuilderSingularSets.BuilderSingularSetsBuilder<T> octopodes(final java.util.Collection<? extends Number> octopodes) {
+    public @java.lang.SuppressWarnings("all") @lombok.Generated BuilderSingularSets.BuilderSingularSetsBuilder<T> octopodes(final java.util.Collection<? extends Number> octopodes) {
       if ((octopodes == null))
           {
             throw new java.lang.NullPointerException("octopodes cannot be null");
@@ -47,18 +47,18 @@ import lombok.Singular;
       this.octopodes.addAll(octopodes);
       return this;
     }
-    public @java.lang.SuppressWarnings("all") BuilderSingularSets.BuilderSingularSetsBuilder<T> clearOctopodes() {
+    public @java.lang.SuppressWarnings("all") @lombok.Generated BuilderSingularSets.BuilderSingularSetsBuilder<T> clearOctopodes() {
       if ((this.octopodes != null))
           this.octopodes.clear();
       return this;
     }
-    public @java.lang.SuppressWarnings("all") BuilderSingularSets.BuilderSingularSetsBuilder<T> rawSet(final java.lang.Object rawSet) {
+    public @java.lang.SuppressWarnings("all") @lombok.Generated BuilderSingularSets.BuilderSingularSetsBuilder<T> rawSet(final java.lang.Object rawSet) {
       if ((this.rawSet == null))
           this.rawSet = new java.util.ArrayList<java.lang.Object>();
       this.rawSet.add(rawSet);
       return this;
     }
-    public @java.lang.SuppressWarnings("all") BuilderSingularSets.BuilderSingularSetsBuilder<T> rawSet(final java.util.Collection<?> rawSet) {
+    public @java.lang.SuppressWarnings("all") @lombok.Generated BuilderSingularSets.BuilderSingularSetsBuilder<T> rawSet(final java.util.Collection<?> rawSet) {
       if ((rawSet == null))
           {
             throw new java.lang.NullPointerException("rawSet cannot be null");
@@ -68,18 +68,18 @@ import lombok.Singular;
       this.rawSet.addAll(rawSet);
       return this;
     }
-    public @java.lang.SuppressWarnings("all") BuilderSingularSets.BuilderSingularSetsBuilder<T> clearRawSet() {
+    public @java.lang.SuppressWarnings("all") @lombok.Generated BuilderSingularSets.BuilderSingularSetsBuilder<T> clearRawSet() {
       if ((this.rawSet != null))
           this.rawSet.clear();
       return this;
     }
-    public @java.lang.SuppressWarnings("all") BuilderSingularSets.BuilderSingularSetsBuilder<T> stringSet(final String stringSet) {
+    public @java.lang.SuppressWarnings("all") @lombok.Generated BuilderSingularSets.BuilderSingularSetsBuilder<T> stringSet(final String stringSet) {
       if ((this.stringSet == null))
           this.stringSet = new java.util.ArrayList<String>();
       this.stringSet.add(stringSet);
       return this;
     }
-    public @java.lang.SuppressWarnings("all") BuilderSingularSets.BuilderSingularSetsBuilder<T> stringSet(final java.util.Collection<? extends String> stringSet) {
+    public @java.lang.SuppressWarnings("all") @lombok.Generated BuilderSingularSets.BuilderSingularSetsBuilder<T> stringSet(final java.util.Collection<? extends String> stringSet) {
       if ((stringSet == null))
           {
             throw new java.lang.NullPointerException("stringSet cannot be null");
@@ -89,12 +89,12 @@ import lombok.Singular;
       this.stringSet.addAll(stringSet);
       return this;
     }
-    public @java.lang.SuppressWarnings("all") BuilderSingularSets.BuilderSingularSetsBuilder<T> clearStringSet() {
+    public @java.lang.SuppressWarnings("all") @lombok.Generated BuilderSingularSets.BuilderSingularSetsBuilder<T> clearStringSet() {
       if ((this.stringSet != null))
           this.stringSet.clear();
       return this;
     }
-    public @java.lang.SuppressWarnings("all") BuilderSingularSets<T> build() {
+    public @java.lang.SuppressWarnings("all") @lombok.Generated BuilderSingularSets<T> build() {
       java.util.Set<T> dangerMice;
       switch (((this.dangerMice == null) ? 0 : this.dangerMice.size())) {
       case 0 :
@@ -140,7 +140,7 @@ import lombok.Singular;
       }
       return new BuilderSingularSets<T>(dangerMice, octopodes, rawSet, stringSet);
     }
-    public @java.lang.Override @java.lang.SuppressWarnings("all") java.lang.String toString() {
+    public @java.lang.Override @java.lang.SuppressWarnings("all") @lombok.Generated java.lang.String toString() {
       return (((((((("BuilderSingularSets.BuilderSingularSetsBuilder(dangerMice=" + this.dangerMice) + ", octopodes=") + this.octopodes) + ", rawSet=") + this.rawSet) + ", stringSet=") + this.stringSet) + ")");
     }
   }
@@ -148,14 +148,14 @@ import lombok.Singular;
   private @Singular SortedSet<? extends Number> octopodes;
   private @SuppressWarnings("all") @Singular("rawSet") Set rawSet;
   private @Singular("stringSet") Set<String> stringSet;
-  @java.lang.SuppressWarnings("all") BuilderSingularSets(final Set<T> dangerMice, final SortedSet<? extends Number> octopodes, final Set rawSet, final Set<String> stringSet) {
+  @java.lang.SuppressWarnings("all") @lombok.Generated BuilderSingularSets(final Set<T> dangerMice, final SortedSet<? extends Number> octopodes, final Set rawSet, final Set<String> stringSet) {
     super();
     this.dangerMice = dangerMice;
     this.octopodes = octopodes;
     this.rawSet = rawSet;
     this.stringSet = stringSet;
   }
-  public static @java.lang.SuppressWarnings("all") <T>BuilderSingularSets.BuilderSingularSetsBuilder<T> builder() {
+  public static @java.lang.SuppressWarnings("all") @lombok.Generated <T>BuilderSingularSets.BuilderSingularSetsBuilder<T> builder() {
     return new BuilderSingularSets.BuilderSingularSetsBuilder<T>();
   }
-}
\ No newline at end of file
+}
