@@ -1,6 +1,6 @@
 @lombok.AllArgsConstructor class ConstructorsConfiguration {
   int x;
-  public @java.lang.SuppressWarnings("all") ConstructorsConfiguration(final int x) {
+  public @java.lang.SuppressWarnings("all") @lombok.Generated ConstructorsConfiguration(final int x) {
     super();
     this.x = x;
   }
