@@ -9,14 +9,14 @@ class DelegateOnGetter {
   DelegateOnGetter() {
     super();
   }
-  public @Delegate @java.lang.SuppressWarnings({"all", "unchecked"}) Bar getBar() {
-    java.lang.Object value = this.bar.get();
-    if ((value == null))
+  public @Delegate @java.lang.SuppressWarnings({"all", "unchecked"}) @lombok.Generated Bar getBar() {
+    java.lang.Object $value = this.bar.get();
+    if (($value == null))
         {
           synchronized (this.bar)
             {
-              value = this.bar.get();
-              if ((value == null))
+              $value = this.bar.get();
+              if (($value == null))
                   {
                     final Bar actualValue = new Bar() {
                       x() {
@@ -28,17 +28,17 @@ class DelegateOnGetter {
                         return 42;
                       }
                     };
-                    value = ((actualValue == null) ? this.bar : actualValue);
-                    this.bar.set(value);
+                    $value = ((actualValue == null) ? this.bar : actualValue);
+                    this.bar.set($value);
                   }
             }
         }
-    return (Bar) ((value == this.bar) ? null : value);
+    return (Bar) (($value == this.bar) ? null : $value);
   }
-  public @java.lang.SuppressWarnings("all") int getInt() {
+  public @java.lang.SuppressWarnings("all") @lombok.Generated int getInt() {
     return this.getBar().getInt();
   }
-  public @java.lang.SuppressWarnings("all") void setList(final java.util.ArrayList<java.lang.String> list) {
+  public @java.lang.SuppressWarnings("all") @lombok.Generated void setList(final java.util.ArrayList<java.lang.String> list) {
     this.getBar().setList(list);
   }
 }
