@@ -9,13 +9,13 @@ class DelegateWithDeprecated {
   DelegateWithDeprecated() {
     super();
   }
-  public @java.lang.Deprecated @java.lang.SuppressWarnings("all") void deprecatedAnnotation() {
+  public @java.lang.Deprecated @java.lang.SuppressWarnings("all") @lombok.Generated void deprecatedAnnotation() {
     this.bar.deprecatedAnnotation();
   }
-  public @java.lang.Deprecated @java.lang.SuppressWarnings("all") void deprecatedComment() {
+  public @java.lang.Deprecated @java.lang.SuppressWarnings("all") @lombok.Generated void deprecatedComment() {
     this.bar.deprecatedComment();
   }
-  public @java.lang.SuppressWarnings("all") void notDeprecated() {
+  public @java.lang.SuppressWarnings("all") @lombok.Generated void notDeprecated() {
     this.bar.notDeprecated();
   }
 }
