@@ -4,7 +4,7 @@ public interface EqualsAndHashCodeWithGenericsOnInnersInInterfaces<A> {
     Inner() {
       super();
     }
-    public @java.lang.Override @java.lang.SuppressWarnings("all") boolean equals(final java.lang.Object o) {
+    public @java.lang.Override @java.lang.SuppressWarnings("all") @lombok.Generated boolean equals(final java.lang.Object o) {
       if ((o == this))
           return true;
       if ((! (o instanceof EqualsAndHashCodeWithGenericsOnInnersInInterfaces.Inner)))
@@ -16,10 +16,10 @@ public interface EqualsAndHashCodeWithGenericsOnInnersInInterfaces<A> {
           return false;
       return true;
     }
-    protected @java.lang.SuppressWarnings("all") boolean canEqual(final java.lang.Object other) {
+    protected @java.lang.SuppressWarnings("all") @lombok.Generated boolean canEqual(final java.lang.Object other) {
       return (other instanceof EqualsAndHashCodeWithGenericsOnInnersInInterfaces.Inner);
     }
-    public @java.lang.Override @java.lang.SuppressWarnings("all") int hashCode() {
+    public @java.lang.Override @java.lang.SuppressWarnings("all") @lombok.Generated int hashCode() {
       final int PRIME = 59;
       int result = 1;
       result = ((result * PRIME) + this.x);
@@ -27,4 +27,3 @@ public interface EqualsAndHashCodeWithGenericsOnInnersInInterfaces<A> {
     }
   }
 }
-
