@@ -1,12 +1,12 @@
 import lombok.experimental.FieldNameConstants;
 import lombok.AccessLevel;
 public @FieldNameConstants(level = AccessLevel.PACKAGE) class FieldNameConstantsBasic {
-  static final @java.lang.SuppressWarnings("all") class Fields {
+  static final @java.lang.SuppressWarnings("all") @lombok.Generated class Fields {
     public static final java.lang.String iAmADvdPlayer = "iAmADvdPlayer";
     public static final java.lang.String butPrintMePlease = "butPrintMePlease";
     <clinit>() {
     }
-    private @java.lang.SuppressWarnings("all") Fields() {
+    private @java.lang.SuppressWarnings("all") @lombok.Generated Fields() {
       super();
     }
   }
@@ -20,4 +20,4 @@ public @FieldNameConstants(level = AccessLevel.PACKAGE) class FieldNameConstants
   public FieldNameConstantsBasic() {
     super();
   }
-}
\ No newline at end of file
+}
