@@ -1,11 +1,11 @@
 import lombok.experimental.FieldNameConstants;
 import lombok.AccessLevel;
 public @FieldNameConstants(onlyExplicitlyIncluded = true,asEnum = true,innerTypeName = "TypeTest") class FieldNameConstantsEnum {
-  public @java.lang.SuppressWarnings("all") enum TypeTest {
+  public @java.lang.SuppressWarnings("all") @lombok.Generated enum TypeTest {
     iAmADvdPlayer(),
     $dontSkipMe(),
     alsoDontSkipMe(),
-    private @java.lang.SuppressWarnings("all") TypeTest() {
+    private @java.lang.SuppressWarnings("all") @lombok.Generated TypeTest() {
       super();
     }
     <clinit>() {
@@ -20,4 +20,4 @@ public @FieldNameConstants(onlyExplicitlyIncluded = true,asEnum = true,innerType
   public FieldNameConstantsEnum() {
     super();
   }
-}
\ No newline at end of file
+}
