@@ -3,7 +3,7 @@ class GeneratedOffJavaxOn {
   GeneratedOffJavaxOn() {
     super();
   }
-  public @java.lang.SuppressWarnings("all") @javax.annotation.Generated("lombok") int getX() {
+  public @java.lang.SuppressWarnings("all") @javax.annotation.Generated("lombok") @lombok.Generated int getX() {
     return this.x;
   }
 }
