@@ -1,7 +1,7 @@
 class A {
   @lombok.AllArgsConstructor class B {
     String s;
-    public @java.lang.SuppressWarnings("all") B(final String s) {
+    public @java.lang.SuppressWarnings("all") @lombok.Generated B(final String s) {
       super();
       this.s = s;
     }
@@ -20,10 +20,10 @@ class C {
   }
 };
     }
-    public @java.lang.SuppressWarnings("all") A getA() {
+    public @java.lang.SuppressWarnings("all") @lombok.Generated A getA() {
       return this.a;
     }
-    public @java.lang.Override @java.lang.SuppressWarnings("all") boolean equals(final java.lang.Object o) {
+    public @java.lang.Override @java.lang.SuppressWarnings("all") @lombok.Generated boolean equals(final java.lang.Object o) {
       if ((o == this))
           return true;
       if ((! (o instanceof C.D)))
@@ -35,17 +35,17 @@ class C {
           return false;
       return true;
     }
-    public @java.lang.Override @java.lang.SuppressWarnings("all") int hashCode() {
+    public @java.lang.Override @java.lang.SuppressWarnings("all") @lombok.Generated int hashCode() {
       final int PRIME = 59;
       int result = 1;
       final java.lang.Object $a = this.getA();
       result = ((result * PRIME) + (($a == null) ? 43 : $a.hashCode()));
       return result;
     }
-    public @java.lang.Override @java.lang.SuppressWarnings("all") java.lang.String toString() {
+    public @java.lang.Override @java.lang.SuppressWarnings("all") @lombok.Generated java.lang.String toString() {
       return (("C.D(a=" + this.getA()) + ")");
     }
-    public @java.lang.SuppressWarnings("all") D(final A a) {
+    public @java.lang.SuppressWarnings("all") @lombok.Generated D(final A a) {
       super();
       this.a = a;
     }
