@@ -10,13 +10,13 @@
    * @return A list of booleans to set for this object. This is a Javadoc return that is long
    *         enough to wrap to multiple lines.
    */
-  public @java.lang.SuppressWarnings("all") java.util.List<Boolean> getBooleans() {
+  public @java.lang.SuppressWarnings("all") @lombok.Generated java.util.List<Boolean> getBooleans() {
     return this.booleans;
   }
   /**
    * This is a list of booleans.
    */
-  public @java.lang.SuppressWarnings("all") java.util.List<Boolean> getBooleans2() {
+  public @java.lang.SuppressWarnings("all") @lombok.Generated java.util.List<Boolean> getBooleans2() {
     return this.booleans2;
   }
   /**
@@ -25,7 +25,7 @@
    * @param booleans A list of booleans to set for this object. This is a Javadoc param that is
    *        long enough to wrap to multiple lines.
    */
-  public @java.lang.SuppressWarnings("all") void setBooleans(final java.util.List<Boolean> booleans) {
+  public @java.lang.SuppressWarnings("all") @lombok.Generated void setBooleans(final java.util.List<Boolean> booleans) {
     this.booleans = booleans;
   }
   /**
@@ -34,7 +34,7 @@
    * @param booleans A list of booleans to set for this object. This is a Javadoc param that is
    *        long enough to wrap to multiple lines.
    */
-  public @java.lang.SuppressWarnings("all") void setBooleans2(final java.util.List<Boolean> booleans2) {
+  public @java.lang.SuppressWarnings("all") @lombok.Generated void setBooleans2(final java.util.List<Boolean> booleans2) {
     this.booleans2 = booleans2;
   }
 }
