@@ -9,7 +9,7 @@ class SimpleTypeResolutionSuccess {
   SimpleTypeResolutionSuccess() {
     super();
   }
-  public @java.lang.SuppressWarnings("all") int getX() {
+  public @java.lang.SuppressWarnings("all") @lombok.Generated int getX() {
     return this.x;
   }
 }
