@@ -5,7 +5,7 @@
   ToStringAutoExclude() {
     super();
   }
-  public @java.lang.Override @java.lang.SuppressWarnings("all") java.lang.String toString() {
+  public @java.lang.Override @java.lang.SuppressWarnings("all") @lombok.Generated java.lang.String toString() {
     return (((("ToStringAutoExclude(x=" + this.x) + ", b=") + this.b) + ")");
   }
 }
@@ -16,7 +16,7 @@
   ToStringAutoExclude2() {
     super();
   }
-  public @java.lang.Override @java.lang.SuppressWarnings("all") java.lang.String toString() {
+  public @java.lang.Override @java.lang.SuppressWarnings("all") @lombok.Generated java.lang.String toString() {
     return (((((("ToStringAutoExclude2(x=" + this.x) + ", $a=") + this.$a) + ", b=") + this.b) + ")");
   }
-}
\ No newline at end of file
+}
