@@ -6,7 +6,7 @@ import lombok.ToString;
   ToStringEnum1() {
     super();
   }
-  public @java.lang.Override @java.lang.SuppressWarnings("all") java.lang.String toString() {
+  public @java.lang.Override @java.lang.SuppressWarnings("all") @lombok.Generated java.lang.String toString() {
     return ("ToStringEnum1." + this.name());
   }
 }
@@ -19,7 +19,7 @@ import lombok.ToString;
   ToStringEnum2() {
     super();
   }
-  public @java.lang.Override @java.lang.SuppressWarnings("all") java.lang.String toString() {
+  public @java.lang.Override @java.lang.SuppressWarnings("all") @lombok.Generated java.lang.String toString() {
     return (((((("ToStringEnum2." + this.name()) + "(x=") + this.x) + ", name=") + this.name) + ")");
   }
 }
@@ -31,11 +31,11 @@ class ToStringEnum3 {
     MemberEnum() {
       super();
     }
-    public @java.lang.Override @java.lang.SuppressWarnings("all") java.lang.String toString() {
+    public @java.lang.Override @java.lang.SuppressWarnings("all") @lombok.Generated java.lang.String toString() {
       return ("ToStringEnum3.MemberEnum." + this.name());
     }
   }
   ToStringEnum3() {
     super();
   }
-}
\ No newline at end of file
+}
