@@ -3,7 +3,7 @@
   ToStringExplicitInclude() {
     super();
   }
-  public @java.lang.Override @java.lang.SuppressWarnings("all") java.lang.String toString() {
+  public @java.lang.Override @java.lang.SuppressWarnings("all") @lombok.Generated java.lang.String toString() {
     return "ToStringExplicitInclude()";
   }
 }
