@@ -6,7 +6,7 @@ public class ToStringInAnonymousClass {
       Inner() {
         super();
       }
-      public @java.lang.Override @java.lang.SuppressWarnings("all") java.lang.String toString() {
+      public @java.lang.Override @java.lang.SuppressWarnings("all") @lombok.Generated java.lang.String toString() {
         return (("Inner(string=" + this.string) + ")");
       }
     }
