@@ -1,5 +1,5 @@
-class UtilityClassInner {
-  static final @lombok.experimental.UtilityClass class UtilClass {
+@java.lang.SuppressWarnings("serial") class UtilityClassInner {
+  static final @lombok.experimental.UtilityClass class UtilClass implements java.io.Serializable {
     private @java.lang.SuppressWarnings("all") @lombok.Generated UtilClass() {
       super();
       throw new java.lang.UnsupportedOperationException("This is a utility class and cannot be instantiated");
