@@ -1,6 +1,6 @@
 import java.util.List;
 
-@lombok.Builder
+@lombok.Builder(access = lombok.AccessLevel.PROTECTED)
 class BuilderSimple<T> {
 	private final int noshow = 0;
 	private final int yes;
