@@ -1,8 +1,8 @@
-// version 14:
+// version 16:
 
 import lombok.extern.flogger.Flogger;
 
 class LoggerFloggerRecord {
 	@Flogger
-	record Inner(String x) {}
+	public record Inner(String x) {}
 }
