@@ -15,4 +15,16 @@ class LoggerJulWithDifferentName {
 @Log(topic=LoggerJulWithStaticField.TOPIC)
 class LoggerJulWithStaticField {
 	static final String TOPIC = "StaticField";
+}
+
+@Log
+enum LoggerJulWithEnum {
+	CONSTANT;
+}
+
+class LoggerJulWithInnerEnum {
+	@Log
+	enum Inner {
+		CONSTANT;
+	}
 }
\ No newline at end of file
